==> diaspora_0.5.9.1+debian.orig.tar.gz: diaspora-0.5.9.1/spec/javascripts/app/views/hovercard_view_spec.js <==
describe("app.views.Hovercard", function() {
  context("user not signed in", function() {
    beforeEach(function() {
      logout();
      this.view = new app.views.Hovercard();
    });

    describe("_populateHovercardWith", function() {
      it("doesn't fetch the aspect dropdown", function() {
        spyOn(jQuery, "ajax").and.callThrough();
        this.view.parent = spec.content();
        this.view._populateHovercardWith({});
        expect(jQuery.ajax).not.toHaveBeenCalled();
      });
    });
  });

  context("user signed in", function() {
    beforeEach(function() {
      loginAs(factory.userAttrs());
      this.view = new app.views.Hovercard();
    });

    describe("initialize", function() {
      it("activates hovercards", function() {
        expect(this.view.active).toBeTruthy();
      });
    });

    describe("mouseIsOverElement", function() {
      it("returns false if the element is undefined", function() {
        expect(this.view.mouseIsOverElement(undefined, $.Event())).toBeFalsy();
      });
    });

    describe("_populateHovercard", function() {
      it("prevents global error handling for the ajax call", function() {
        spyOn(jQuery, "ajax").and.callThrough();
        this.view.parent = spec.content();
        this.view._populateHovercard();
        expect(jQuery.ajax).toHaveBeenCalledWith("undefined/hovercard.json", {preventGlobalErrorHandling: true});
      });
    });

    describe("_populateHovercardWith", function() {
      it("prevents global error handling for the ajax call", function() {
        spyOn(jQuery, "ajax").and.callThrough();
        this.view.parent = spec.content();
        this.view._populateHovercardWith({});
        expect(jQuery.ajax).toHaveBeenCalledWith(
          "undefined/aspect_membership_button",
          {preventGlobalErrorHandling: true}
        );
      });
    });
  });
});

==> diaspora_0.6.0.1+debian.orig.tar.gz: diaspora-0.6.0.1/spec/javascripts/app/views/hovercard_view_spec.js <==
describe("app.views.Hovercard", function() {

  afterEach(function() {
    $("body #hovercard_container").remove();
  });

  context("user not signed in", function() {
    beforeEach(function() {
      logout();
      this.view = new app.views.Hovercard();
    });

    describe("_populateHovercard", function() {
      it("doesn't create the aspect dropdown", function() {
        this.view.parent = spec.content();
        this.view._populateHovercard();
        jasmine.Ajax.requests.mostRecent().respondWith({
          status: 200,
          responseText: JSON.stringify({id: 1337})
        });
        expect(this.view.aspectMembershipDropdown).toEqual(undefined);
      });
    });
  });

  context("user signed in", function() {
    beforeEach(function() {
      loginAs(factory.userAttrs());
      this.view = new app.views.Hovercard();
    });

    describe("initialize", function() {
      it("activates hovercards", function() {
        expect(this.view.active).toBeTruthy();
      });
    });

    describe("mouseIsOverElement", function() {
      it("returns false if the element is undefined", function() {
        expect(this.view.mouseIsOverElement(undefined, $.Event())).toBeFalsy();
      });
    });

    describe("_populateHovercard", function() {
      it("prevents global error handling for the ajax call", function() {
        spyOn(jQuery, "ajax").and.callThrough();
        this.view.parent = spec.content();
        this.view._populateHovercard();
        expect(jQuery.ajax).toHaveBeenCalledWith("undefined/hovercard.json", {preventGlobalErrorHandling: true});
      });

      it("creates the aspect dropdown", function() {
        this.view.parent = spec.content();
        this.view._populateHovercard();
        jasmine.Ajax.requests.mostRecent().respondWith({
          status: 200,
          responseText: JSON.stringify({id: 1337})
        });
        expect(this.view.aspectMembershipDropdown).not.toEqual(undefined);
      });
    });
  });
});
